from .registro0 import CNAB240Registro0
from .registro1 import CNAB240Registro1
from .registro3 import CNAB240Registro3
from .registro5 import CNAB240Registro5
from .registro9 import CNAB240Registro9

__all__ = [
    'CNAB240Registro0',
    'CNAB240Registro1',
    'CNAB240Registro3',
    'CNAB240Registro5',
    'CNAB240Registro9',
]
